@@ -15,6 +15,7 @@
 #include <QGraphicsSceneMouseEvent>
 #include <QPainter>
 #include <QAction>
+
 #include <KgDifficulty>
 #include <KgTheme>
 #include <KLocalizedString>
@@ -24,7 +25,6 @@
 #include "kollisionconfig.h"
 
 #include <cmath>
-#include <ctime>
 #include <stdio.h>
 
 struct Collision
@@ -56,6 +56,7 @@ MainArea::MainArea()
 , m_soundBallLeaving(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds/ball_leaving.ogg")))
 , m_soundStart(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds/start.ogg")))
 , m_pauseAction(nullptr)
+, m_random(new QRandomGenerator(QRandomGenerator::global()->generate()))
 {
 
     // Initialize the sound state
@@ -67,8 +68,6 @@ MainArea::MainArea()
     QRect rect(0, 0, m_size, m_size);
     setSceneRect(rect);
 
-    qsrand(std::time(nullptr));
-
     m_timer.setInterval(20);
     connect(&m_timer, &QTimer::timeout, this, &MainArea::tick);
 
@@ -131,7 +130,8 @@ Animation* MainArea::writeMessage(const QString& text)
 Animation* MainArea::writeText(const QString& text, bool fade)
 {
     m_welcomeMsg.clear();
-    foreach (const QString &line, text.split(QLatin1Char('\n'))) {
+    const QStringList lines = text.split(QLatin1Char('\n'));
+    for (const QString &line : lines) {
         m_welcomeMsg.append(
             QExplicitlySharedDataPointer<Message>(new Message(line, m_msgFont, m_size)));
     }
@@ -139,7 +139,7 @@ Animation* MainArea::writeText(const QString& text, bool fade)
 
     if (fade) {
         AnimationGroup* anim = new AnimationGroup;
-        foreach (QExplicitlySharedDataPointer<Message> message, m_welcomeMsg) {
+        for (const auto& message : qAsConst(m_welcomeMsg)) {
             message->setOpacityF(0.0);
             anim->add(new FadeAnimation(message, 0.0, 1.0, 1000));
         }
@@ -156,7 +156,7 @@ Animation* MainArea::writeText(const QString& text, bool fade)
 void MainArea::displayMessages(const QList<QExplicitlySharedDataPointer<Message> >& messages)
 {
     int totalHeight = 0;
-    foreach (QExplicitlySharedDataPointer<Message> message, messages) {
+    for (const auto& message : messages) {
       totalHeight += message->height();
     }
     QPointF pos(m_size / 2.0, (m_size - totalHeight) / 2.0);
@@ -215,18 +215,18 @@ void MainArea::togglePause()
             m_lastGameTime = 0;
         }
 
-        emit changeGameTime(m_lastGameTime);
+        Q_EMIT changeGameTime(m_lastGameTime);
     }
 
     m_man->setVisible(!m_paused);
-    foreach (Ball* ball, m_balls) {
+    for (Ball* ball : qAsConst(m_balls)) {
         ball->setVisible(!m_paused);
     }
-    foreach (Ball* ball, m_fading) {
+    for (Ball* ball : qAsConst(m_fading)) {
         ball->setVisible(!m_paused);
     }
 
-    emit pause(m_paused);
+    Q_EMIT pause(m_paused);
 }
 
 void MainArea::start()
@@ -268,8 +268,8 @@ void MainArea::start()
 
     writeMessage(i18np("%1 ball", "%1 balls", 4));
 
-    emit changeGameTime(0);
-    emit starting();
+    Q_EMIT changeGameTime(0);
+    Q_EMIT starting();
 
     if(m_soundEnabled)
         m_soundStart.start();
@@ -282,14 +282,14 @@ void MainArea::setPauseAction(QAction * action)
 
 QPointF MainArea::randomPoint() const
 {
-    double x = static_cast<double>(qrand()) * (m_size - radius() * 2) / RAND_MAX + radius();
-    double y = static_cast<double>(qrand()) * (m_size - radius() * 2) / RAND_MAX + radius();
+    const double x = m_random->bounded(m_size - radius() * 2) + radius();
+    const double y = m_random->bounded(m_size - radius() * 2) + radius();
     return QPointF(x, y);
 }
 
 QPointF MainArea::randomDirection(double val) const
 {
-    double angle = static_cast<double>(qrand()) * 2 * M_PI / RAND_MAX;
+    const double angle = m_random->bounded(2 * M_PI);
     return QPointF(val * sin(angle), val * cos(angle));
 }
 
@@ -301,7 +301,7 @@ Ball* MainArea::addBall(const QString& id)
 
         done = true;
         pos = randomPoint().toPoint();
-        foreach (Ball* ball, m_fading) {
+        for (Ball* ball : qAsConst(m_fading)) {
             if (collide(pos, ball->position(), m_ballDiameter, m_ballDiameter, tmp)) {
                 done = false;
                 break;
@@ -334,7 +334,7 @@ Ball* MainArea::addBall(const QString& id)
     m_fading.push_back(ball);
 
     // update statusbar
-    emit changeBallNumber(m_balls.size() + m_fading.size());
+    Q_EMIT changeBallNumber(m_balls.size() + m_fading.size());
 
     return ball;
 }
@@ -359,9 +359,9 @@ void MainArea::abort()
         m_man->setVelocity(QPointF(0, 0));
         m_balls.push_back(m_man);
         m_man = nullptr;
-        emit changeState(false);
+        Q_EMIT changeState(false);
 
-        foreach (Ball* fball, m_fading) {
+        for (Ball* fball : qAsConst(m_fading)) {
             fball->setOpacityF(1.0);
             fball->setVelocity(QPointF(0.0, 0.0));
             m_balls.push_back(fball);
@@ -382,7 +382,7 @@ void MainArea::tick()
     // compute game time && update statusbar
     if ((m_time.elapsed() - m_pauseTime - m_penalty) / 1000 > m_lastGameTime) {
         m_lastGameTime = (m_time.elapsed() - m_pauseTime - m_penalty) / 1000;
-        emit changeGameTime(m_lastGameTime);
+        Q_EMIT changeGameTime(m_lastGameTime);
     }
 
     Collision collision;
@@ -401,7 +401,7 @@ void MainArea::tick()
     }
 
     // handle deadly collisions
-    foreach (Ball* ball, m_balls) {
+    for (Ball* ball : qAsConst(m_balls)) {
         if (m_man && collide(
                 ball->position(),
                 m_man->position(),
@@ -416,7 +416,7 @@ void MainArea::tick()
     }
 
     // integrate
-    foreach (Ball* ball, m_balls) {
+    for (Ball* ball : qAsConst(m_balls)) {
         // position
         ball->setPosition(ball->position() +
             ball->velocity() * t);
@@ -522,7 +522,7 @@ void MainArea::tick()
         if (m_increaseBallSize) {
             //increase ball size by 4 units
             setBallDiameter(m_ballDiameter + 4);
-            foreach (Ball* ball, m_balls) {
+            for (Ball* ball : qAsConst(m_balls)) {
                 ball->setRenderSize(QSize(m_ballDiameter, m_ballDiameter));
             }
         }
@@ -542,7 +542,7 @@ void MainArea::tick()
             "GAME OVER\n"
             "You survived for %1 seconds\n"
             "Click to restart", time);
-        emit gameOver(time);
+        Q_EMIT gameOver(time);
         Animation* a = writeText(text);
         connect(this, &MainArea::starting, a, &Animation::stop);
     }
@@ -576,7 +576,7 @@ void MainArea::mousePressEvent(QGraphicsSceneMouseEvent* e)
             addItem(m_man);
 
             start();
-            emit changeState(true);
+            Q_EMIT changeState(true);
         }
     }
 }
