@@ -15,6 +15,9 @@
 #include <QTime>
 #include <QList>
 #include <QGraphicsScene>
+#include <QScopedPointer>
+#include <QRandomGenerator>
+
 #include <KGameRenderer>
 #include <KgSound>
 #include "animator.h"
@@ -80,6 +83,8 @@ private:
 
     QAction * m_pauseAction;
 
+    QScopedPointer<QRandomGenerator> m_random;
+
     double radius() const;
     void setBallDiameter(int val);
 
@@ -103,13 +108,13 @@ public:
     MainArea();
     void start();
     void setPauseAction(QAction * action);
-public slots:
+public Q_SLOTS:
     void tick();
     void increaseBallSize(bool enable);
     void enableSounds(bool enable);
     void abort();
     void togglePause();
-signals:
+Q_SIGNALS:
     void starting();
     void gameOver(int);
     void changeBallNumber(int);
